from django.db import models


class Country(models.Model):
    name = models.CharField(max_length=200)
    code = models.CharField(max_length=2, unique=True)

    class Meta:
        ordering = ('name',)
        verbose_name_plural = 'countries'

    def __unicode__(self):
        return self.name




from setuptools import setup, find_packages

from countries import get_version


setup(
    name = 'incuna-countries',
    packages = find_packages(),
    include_package_data=True,
    version = get_version(),
    description = 'Countries model and fixtures.',
    author = 'Incuna Ltd',
    author_email = 'dev@incuna.com',
    url = 'http://incuna.com/',
)

